@@ -108,6 +108,11 @@ namespace facter { namespace facts {
          */
         constexpr static char const* kvm = "kvm";
 
+        /**
+         * The name for AHV (Nutanix) virtual machine.
+         */
+        constexpr static char const* ahv = "ahv";
+
         /**
          * The name for Bochs virtual machine.
          */
@@ -147,6 +152,11 @@ namespace facter { namespace facts {
          * The name for OpenBSD vmm
          */
         constexpr static char const* vmm = "vmm";
+
+        /**
+         * The name for FreeBSD bhyve
+         */
+        constexpr static char const* bhyve = "bhyve";
     };
 
 }}  // namespace facter::facts
